import unittest
from yearfrac import d30360e


class Test_d30360e(unittest.TestCase):

    def test1(self):
        x = d30360e(2018, 12, 15, 2019, 3, 1, False)
        self.assertEquals(round(x, 8), 0.21111111)

    def test2(self):
        x = d30360e(2018, 12, 15, 2019, 3, 1, True)
        self.assertEquals(round(x, 8), 0.21111111)


# run
if __name__ == '__main__':
    unittest.main()



import unittest
from yearfrac import yearfrac
from datetime import datetime


class Test_Yearfrac(unittest.TestCase):

    def test1(self):
        d1 = datetime(2018, 12, 15)
        d2 = datetime(2019, 3, 1)
        x = yearfrac(d1, d2, 'act')
        self.assertEquals(round(x, 8), 0.20547945)

    def test2(self):
        d1 = datetime(2018, 12, 15)
        d2 = datetime(2019, 3, 1)
        x = yearfrac(d1, d2, 'act_isda')
        self.assertEquals(round(x, 8), 0.20547945)

    def test3(self):
        d1 = datetime(2018, 12, 15)
        d2 = datetime(2019, 3, 1)
        x = yearfrac(d1, d2, '30e360')
        self.assertEquals(round(x, 8), 0.21111111)

    def test4(self):
        d1 = datetime(2018, 12, 15)
        d2 = datetime(2019, 3, 1)
        x = yearfrac(d1, d2, '30e360_matu')
        self.assertEquals(round(x, 8), 0.21111111)


# run
if __name__ == '__main__':
    unittest.main()




import datetime
from .act_isda import act_isda
from .act_afb import act_afb
from .d30360e import d30360e
from .d30365 import d30365


def yearfrac(d1, d2, method='act'):
    if not isinstance(d1, (datetime.datetime, datetime.date)):
        raise Exception("d1 is not a datetime object.")

    if not isinstance(d2, (datetime.datetime, datetime.date)):
        raise Exception("d2 is not a datetime object.")

    if method.lower() in ('act', 'act_afb', 'afb'):
        return act_afb(
            d1.year, d1.month, d1.day,
            d2.year, d2.month, d2.day)
    elif method.lower() in ('act_isda'):
        return act_isda(
            d1.year, d1.month, d1.day,
            d2.year, d2.month, d2.day)
    elif method.lower() in ('d30360e', '30e360'):
        return d30360e(
            d1.year, d1.month, d1.day,
            d2.year, d2.month, d2.day,
            False)
    elif method.lower() in ('d30360e_matu', '30e360_matu'):
        return d30360e(
            d1.year, d1.month, d1.day,
            d2.year, d2.month, d2.day,
            True)
    elif method.lower() in ('30365'):
        return d30365(
            d1.year, d1.month, d1.day,
            d2.year, d2.month, d2.day)
    else:
        raise Exception("no method {0:s}".format(method))



import unittest
from yearfrac import date_to_jd, jd_to_date


class Test_JulianDay(unittest.TestCase):
    def test1(self):
        # 24-Nov (-4713) 12Uhr
        y, m, d = jd_to_date(0)
        # print("\nDate: {0:04d}-{1:02d}-{2:02d}".format(y, m, d))
        self.assertEquals(y, -4713)
        self.assertEquals(m, 11)
        self.assertEquals(d, 24)

    def test2(self):
        # 25-Nov (-4713) 12Uhr
        y, m, d = jd_to_date(1)
        # print("\nDate: {0:04d}-{1:02d}-{2:02d}".format(y, m, d))
        self.assertEquals(y, -4713)
        self.assertEquals(m, 11)
        self.assertEquals(d, 25)

    def test3(self):
        # 11-Feb-2014 12Uhr, 2456700
        y, m, d = jd_to_date(2456700)
        # print("\nDate: {0:04d}-{1:02d}-{2:02d}".format(y, m, d))
        self.assertEquals(y, 2014)
        self.assertEquals(m, 2)
        self.assertEquals(d, 11)

    def test4(self):
        # 27-Feb-6700 12Uhr, 4168242
        y, m, d = jd_to_date(4168242)
        # print("\nDate: {0:04d}-{1:02d}-{2:02d}".format(y, m, d))
        self.assertEquals(y, 6700)
        self.assertEquals(m, 2)
        self.assertEquals(d, 27)

    def test5(self):
        # 28-Feb-6700 12Uhr, 4168243
        y, m, d = jd_to_date(4168243)
        # print("\nDate: {0:04d}-{1:02d}-{2:02d}".format(y, m, d))
        self.assertEquals(y, 6700)
        self.assertEquals(m, 2)
        self.assertEquals(d, 28)

    def test6(self):
        # 01-Mar-6700 12Uhr, 4168244
        y, m, d = jd_to_date(4168244)
        # print("\nDate: {0:04d}-{1:02d}-{2:02d}".format(y, m, d))
        self.assertEquals(y, 6700)
        self.assertEquals(m, 3)
        self.assertEquals(d, 1)

    def test7(self):
        # 02-Mar-6700 12Uhr, 4168245
        y, m, d = jd_to_date(4168245)
        # print("\nDate: {0:04d}-{1:02d}-{2:02d}".format(y, m, d))
        self.assertEquals(y, 6700)
        self.assertEquals(m, 3)
        self.assertEquals(d, 2)


if __name__ == '__main__':
    unittest.main()



from .isaleapyear import isaleapyear
from .julianday import date_to_jd, jd_to_date
from .act_isda import act_isda
from .act_afb import act_afb
from .d30360e import d30360e
from .d30365 import d30365
from .yearfrac import yearfrac
